uniform lowp float centerx;
uniform lowp float centery;
uniform lowp float radius1;
uniform lowp float radius2;
uniform lowp float distortionstrength;
uniform lowp float chromaticoffset;
uniform lowp float ringblur;

/////////////////////////////////////////////////////////
// Shockwave

//The current foreground texture co-ordinate
varying mediump vec2 vTex;
//The foreground texture sampler, to be sampled at vTex
uniform lowp sampler2D samplerFront;
//The current foreground rectangle being rendered
uniform mediump vec2 srcStart;
uniform mediump vec2 srcEnd;
//The current foreground source rectangle being rendered
uniform mediump vec2 srcOriginStart;
uniform mediump vec2 srcOriginEnd;
//The current foreground source rectangle being rendered, in layout 
uniform mediump vec2 layoutStart;
uniform mediump vec2 layoutEnd;
//The background texture sampler used for background - blending effects
uniform lowp sampler2D samplerBack;
//The current background rectangle being rendered to, in texture co-ordinates, for background-blending effects
uniform mediump vec2 destStart;
uniform mediump vec2 destEnd;
//The time in seconds since the runtime started. This can be used for animated effects
uniform mediump float seconds;
//The size of a texel in the foreground texture in texture co-ordinates
uniform mediump vec2 pixelSize;
//The current layer scale as a factor (i.e. 1 is unscaled)
uniform mediump float layerScale;
//The current layer angle in radians.
uniform mediump float layerAngle;

void main(void)
{
	mediump vec2 iResolution = 1.0 / pixelSize;
    mediump vec2 uv = vTex;
    mediump vec2 fragCoord = uv * iResolution;
	mediump vec2 scaledUV = fragCoord/iResolution.x;
    
    mediump vec2 center = vec2(centerx , centery * iResolution.y / iResolution.x);
    
    mediump float dist = distance(scaledUV , center);
    
    //first circle
    mediump float mask = 1. - smoothstep(radius1 - ringblur , radius1 , dist);
    
    //subtract second circle to form a ring
    mask -= 1. - smoothstep(radius2 - ringblur , radius2 , dist);
    
    mediump vec2 distortion = normalize(scaledUV - center) * mask * distortionstrength;

    mediump float chromaStrength = chromaticoffset * mask;

    mediump vec4 mainCol = vec4(
	    texture2D(samplerFront , uv - distortion + chromaStrength).r,
	    texture2D(samplerFront, uv - distortion).g,
	    texture2D(samplerFront, uv - distortion - chromaStrength).b,
	    texture2D(samplerFront, uv).a
    );
    
    gl_FragColor = mainCol;
}